function [features_Pmat] = extractFeaturesFromPowerSpectrum(features_inp,A_inp,signal_inp)

% initialization of the output variable
features_Pmat =[];

% checking that the last Diastole phase is sufficiently long using a minimun length threshold of mean - 1*SD
% featuresMat column 9 and 10 stores mean_IntDia (mean value of diastole intervals) and sd_IntDia (SD value of diastole intervals)
length_threshold = features_inp(1,9) - features_inp(1,10);

% temporary storage matrix for the ratios of energy
Tmat_S1=[]; Tmat_sys=[]; Tmat_S2=[]; Tmat_dia=[];

% looping through all cardiac cycle using the information stored in A_inp
% each row of A_inp correspond to 1 cardiac cycle: S1 - systole - S2 - Diastole
Nrows = size(A_inp,1);
for j=1:Nrows
    
    % looping through the 4 assigned states
    for k=1:4
        
        if(k==4)
            if(j==Nrows)
                sindex = A_inp(j,k)+1; eindex = size(signal_inp,1);
            else
                sindex = A_inp(j,k)+1; eindex = A_inp(j+1,1);
            end
        else
            sindex = A_inp(j,k)+1; eindex = A_inp(j,k+1);
        end
        
        % this is the resampled signal for the kth state for the jth cycle
        % performing the FFT for this signal and computing the power spectrum
        yvect = signal_inp(sindex:eindex,1);
        
        % ensuring that Num will always be an integer - if the size of yvect is not even
        % Question mark on how this rounding will affect the power spectrum of vector with odd length?
        Num = round(size(yvect,1)/2); pvect = abs(fft(yvect))/Num;
        powervect = pvect(1:Num).^2;
        powervect_s = sort(powervect,'descend');
        
        % computing the sum of the power for the 5th and 10th highest peaks
        Nlimit1 = 5; Nlimit2 = 10;
        % additional check on the last diastole segment
        if(j==Nrows)
            if((eindex-sindex)>length_threshold)
                p1 = sum(powervect_s(1:Nlimit1)); p2 = sum(powervect_s(1:Nlimit2)); p3 = sum(powervect_s);
                % checking for zero intensity during this segment
                if(p3==0)
                    r1=[];r2=[];
                else
                    r1 = p1/p3; r2 = p2/p3;
                end
            else
                r1=[];r2=[];
            end
        else
            p1 = sum(powervect_s(1:Nlimit1)); p2 = sum(powervect_s(1:Nlimit2)); p3 = sum(powervect_s);
            % checking for zero intensity during this segment
            if(p3==0)
                r1=[];r2=[];
            else
                r1 = p1/p3; r2 = p2/p3;
            end
        end
        
        % storing the ratios into the temporary storage matrix
        if(k==1)
            Tmat_S1 = [Tmat_S1; r1,r2];
        elseif(k==2)
            Tmat_sys = [Tmat_sys; r1,r2];
        elseif(k==3)
            Tmat_S2 = [Tmat_S2; r1,r2];
        elseif(k==4)
            Tmat_dia = [Tmat_dia; r1,r2];
        end
        
    end  % end of for k=1:4 loop
    
end  % end of for j=1:size(A_inp,1) loop

% computing the mean and SD for the respective power ratios
features_Pmat(1,:) = [mean(Tmat_S1(:,1)),std(Tmat_S1(:,1)),mean(Tmat_S1(:,2)),std(Tmat_S1(:,2)),...
    mean(Tmat_sys(:,1)),std(Tmat_sys(:,1)),mean(Tmat_sys(:,2)),std(Tmat_sys(:,2)),...
    mean(Tmat_S2(:,1)),std(Tmat_S2(:,1)),mean(Tmat_S2(:,2)),std(Tmat_S2(:,2)),...
    mean(Tmat_dia(:,1)),std(Tmat_dia(:,1)),mean(Tmat_dia(:,2)),std(Tmat_dia(:,2))];
